@@ -36,7 +36,7 @@ class BDDXMLWriter(object):
             from lxml import etree
         except ImportError:
             raise RadishError(
-                'if you want to use the BDD xml writer you have to "pip install radish-bdd[bdd-xml]"'
+                'if you want to use the BDD xml writer you have to install extra packages: "pip install radish-bdd[bdd-xml]"'
             )
 
         after.all(self.generate_bdd_xml)
