@@ -1,12 +1,9 @@
 # -*- coding: utf-8 -*-
 
 """
-    This radish extension provides the functionality to write the feature file run to the console.
+This radish extension provides the functionality to write the feature file run to the console.
 """
 
-from __future__ import unicode_literals
-from __future__ import print_function
-
 # disable no-member lint error because of dynamic method from colorful
 # pylint: disable=no-member
 
@@ -22,17 +19,12 @@ from radish.scenarioloop import ScenarioLoop
 from radish.stepmodel import Step
 from radish.extensionregistry import extension
 from radish.utils import console_write as write
-from radish.compat import PY2
-
-
-if PY2:
-    str = unicode
 
 
 @extension
 class ConsoleWriter(object):
     """
-        Console writer radish extension
+    Console writer radish extension
     """
 
     OPTIONS = [
@@ -65,7 +57,7 @@ class ConsoleWriter(object):
 
     def get_color_func(self, state):
         """
-            Returns the color func to use
+        Returns the color func to use
         """
         if state == Step.State.PASSED:
             return colorful.bold_green
@@ -78,7 +70,7 @@ class ConsoleWriter(object):
 
     def get_line_jump_seq(self):
         """
-            Returns the line jump ANSI sequence
+        Returns the line jump ANSI sequence
         """
         line_jump_seq = ""
         if (
@@ -91,11 +83,11 @@ class ConsoleWriter(object):
 
     def get_id_sentence_prefix(self, model, color_func, max_rows=None):
         """
-            Returns the id from a model as sentence prefix
+        Returns the id from a model as sentence prefix
 
-            :param Model model: a model with an id property
-            :param function color_func: a function which gives coloring
-            :param int max_rows: the maximum rows. Used for padding
+        :param Model model: a model with an id property
+        :param function color_func: a function which gives coloring
+        :param int max_rows: the maximum rows. Used for padding
         """
         padding = len("{0}. ".format(max_rows)) if max_rows else 0
         return (
@@ -106,7 +98,7 @@ class ConsoleWriter(object):
 
     def get_id_padding(self, max_rows, offset=0):
         """
-            Returns the id padding
+        Returns the id padding
         """
         if not world.config.write_ids:
             return ""
@@ -115,7 +107,7 @@ class ConsoleWriter(object):
 
     def get_table_col_widths(self, table):
         """
-            Returns the width for every column of a table (lists in list)
+        Returns the width for every column of a table (lists in list)
         """
         return [
             max(len(str(col)) for col in row) for row in zip(*table)
@@ -123,9 +115,9 @@ class ConsoleWriter(object):
 
     def console_writer_before_each_feature(self, feature):
         """
-            Writes feature header to the console
+        Writes feature header to the console
 
-            :param Feature feature: the feature to write to the console
+        :param Feature feature: the feature to write to the console
         """
         output = ""
         for tag in feature.tags:
@@ -156,9 +148,9 @@ class ConsoleWriter(object):
 
     def console_writer_before_each_scenario(self, scenario):
         """
-            Writes the scenario header to the console
+        Writes the scenario header to the console
 
-            :param Scenario scenario: the scenario to write to the console
+        :param Scenario scenario: the scenario to write to the console
         """
         output = "\n"
         if isinstance(scenario.parent, ScenarioOutline):
@@ -192,7 +184,7 @@ class ConsoleWriter(object):
             )
             colored_pipe = colorful.bold_white("|")
             output = "        {0}{1} {2: <18} {1}".format(
-                id_prefix, colored_pipe, str(colorful.bold_yellow(scenario.iteration))
+                id_prefix, colored_pipe, colorful.bold_yellow(str(scenario.iteration))
             )
         else:
             id_prefix = self.get_id_sentence_prefix(scenario, colorful.bold_cyan)
@@ -222,9 +214,9 @@ class ConsoleWriter(object):
 
     def console_writer_before_each_step(self, step):
         """
-            Writes the step to the console before it is run
+        Writes the step to the console before it is run
 
-            :param Step step: the step to write to the console
+        :param Step step: the step to write to the console
         """
         if not isinstance(step.parent.parent, Feature):
             return
@@ -328,9 +320,9 @@ class ConsoleWriter(object):
 
     def console_writer_after_each_step(self, step):
         """
-            Writes the step to the console after it was run
+        Writes the step to the console after it was run
 
-            :param Step step: the step to write to the console
+        :param Step step: the step to write to the console
         """
         if not isinstance(step.parent.parent, Feature):
             return
@@ -424,9 +416,9 @@ class ConsoleWriter(object):
 
     def console_writer_after_each_scenario(self, scenario):
         """
-            If the scenario is a ExampleScenario it will write the Examples header
+        If the scenario is a ExampleScenario it will write the Examples header
 
-            :param Scenario scenario: the scenario which was ran.
+        :param Scenario scenario: the scenario which was ran.
         """
         output = ""
         if isinstance(scenario, ScenarioOutline):
@@ -445,7 +437,7 @@ class ConsoleWriter(object):
         elif isinstance(scenario, ScenarioLoop):
             output += "\n    {0}: {1}".format(
                 colorful.bold_white(scenario.iterations_keyword),
-                colorful.cyan(scenario.iterations),
+                colorful.cyan(str(scenario.iterations)),
             )
         elif isinstance(scenario.parent, ScenarioOutline):
             colored_pipe = colorful.bold_white("|")
@@ -494,7 +486,7 @@ class ConsoleWriter(object):
                     scenario, colorful.bold_cyan, len(scenario.parent.scenarios)
                 ),
                 colored_pipe,
-                str(color_func(scenario.iteration)),
+                color_func(str(scenario.iteration)),
             )
 
             if scenario.state == Step.State.FAILED:
@@ -522,8 +514,8 @@ class ConsoleWriter(object):
         self, feature
     ):  # pylint: disable=unused-argument
         """
-            Writes a newline after each feature
+        Writes a newline after each feature
 
-            :param Feature feature: the feature which was ran.
+        :param Feature feature: the feature which was ran.
         """
         write("")
